======================
 ``zope.browsermenu``
======================

.. image:: https://img.shields.io/pypi/v/zope.browsermenu.svg
        :target: https://pypi.python.org/pypi/zope.browsermenu/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.browsermenu.svg
        :target: https://pypi.org/project/zope.browsermenu/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.browsermenu/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.browsermenu/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.browsermenu/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.browsermenu?branch=master

.. note::
   This package is at present not reusable without depending on a large
   chunk of the Zope Toolkit and its assumptions. It is maintained by the
   `Zope Toolkit project <http://docs.zope.org/zopetoolkit/>`_.

This package provides an implementation of browser menus and ZCML directives
for configuring them.
